@@ -920,18 +920,21 @@ def main():
             
             with open(f"summary.md", "w", encoding="utf-8") as file:
                 file.write(f"### Last Update : Stats from {start_date_utc} to {end_date_utc} (UTC Timezone)\n\n")
-                file.write(f"### {summary_text}\n")
-                file.write(f"### {thread_summary}\n")
+                file.write(f"#### {summary_text}\n")
+                file.write(f"#### {thread_summary}\n")
                 top_users ="\nTop 5 Users are : \n"
                 for i in range(0,4 if len(df)>4 else len(df)):
                     top_users += f"- {df.loc[i, 'name']} : {humanize.intword(df.loc[i, 'map_changes'])} Map Changes\n"
                 file.write(top_users) 
 
+                user_tags_summary="\nSummary of Supplied Tags\n"
+                user_tag = 'poi'
+                user_tags_summary+=f"- {user_tag} = Created: {humanize.intword(df[f'{user_tag}.create'].sum())}, Modified : {humanize.intword(df[f'{user_tag}.modify'].sum())}\n"
+
                 if args.tags:
-                    user_tags_summary="\nSummary of Supplied Tags\n"
                     for user_tag in args.tags:
                         user_tags_summary+=f"- {user_tag} = Created: {humanize.intword(df[f'{user_tag}.create'].sum())}, Modified : {humanize.intword(df[f'{user_tag}.modify'].sum())}\n"
-                    file.write(f"{user_tags_summary}\n")
+                file.write(f"{user_tags_summary}\n")
 
                 if args.all_tags:
                     # Apply the sum_tags function to the tags column
